@@ -115,7 +115,8 @@ def _pose_unpacker(value: bytes) -> dict:
     R = | Vyx Vyy Vyz |
         | Vzx Vzy Vzz |
     """
-    floats = Struct("<ffffffffffff").unpack(value)
+    floats = np.array(Struct("<ffffffffffff").unpack(value), dtype=np.float32)
+
     # we have to transpose rotation matrices because values
     # are received column by column and not line by line
     return {
@@ -132,7 +133,10 @@ def _pose_array_unpacker(value: bytes) -> List:
     R = | Vyx Vyy Vyz |
         | Vzx Vzy Vzz |
     """
-    floats = np.array(list(Struct("<ffffffffffff").iter_unpack(value)), ndmin=2)
+    floats = np.array(
+        list(Struct("<ffffffffffff").iter_unpack(value)), ndmin=2, dtype=np.float32
+    )
+
     translations = floats[:, 0:3]
     rotations = np.transpose(floats[:, 3:].reshape((-1, 3, 3)), axes=[0, 2, 1])
     # we have to transpose rotation matrices because values
