@@ -1,5 +1,5 @@
 """OSEF private types definition."""
-__version__ = "1.4.0"
+__version__ = "1.6.1"
 
 # Standard imports
 from enum import Enum, IntEnum
@@ -81,6 +81,14 @@ class OsefTypes(IntEnum):
     _INTERACTIVE_RESPONSE_PINGPONG = 68
     _HEIGHT_MAP = 69
     _HEIGHT_MAP_POINTS = 70
+    DIVERGENCE_INDICATOR = 71
+    _CARLA_TAG_ARRAY = 72
+    _BACKGROUND_SCENE_PARAMS = 73
+    _BACKGROUND_SCENE_PARAMS_GENERAL = 74
+    _BACKGROUND_SCENE_PARAMS_ELEVATIONS = 75
+    _BACKGROUND_SCENE_FRAGMENT = 76
+    _BACKGROUND_SCENE_FRAGMENT_INFO = 77
+    _BACKGROUND_SCENE_FRAGMENT_DISTANCES = 78
 
 
 class OsefKeys(Enum):
@@ -110,6 +118,7 @@ class OsefKeys(Enum):
     - none or one:     Elevations                     (ELEVATIONS)
     - none or one:     Distances                      (DISTANCES)
     - none or one:     Road Markings Bits             (ROAD_MARKINGS_BITS)
+    - none or one:     Carla Tag Array                (CARLA_TAG_ARRAY)
     """
     AUGMENTED_CLOUD = "augmented_cloud"
 
@@ -272,7 +281,8 @@ class OsefKeys(Enum):
     Class ID Array
     **Output when**: Tracking is enabled.
     **Format**: list of signed 32 bits integers, using enum CLASS ID.
-    **Purpose**: Contains list of class IDs.
+    **Purpose**: Contains list of class IDs. For further details, see:
+    [Classification](https://docs.outsight.ai/software/understanding-osef-data/object-tracking-data#classification)
     """
     CLASS_ID_ARRAY = "class_id_array"
 
@@ -333,7 +343,7 @@ class OsefKeys(Enum):
     **Coordinate Frame**:
     Absolute/World Frame, which is:
     - Ego-Motion: Initial pose of the LiDAR.
-    - Relocalisation: Map Coordinate Frame.
+    - Relocalization: Map Coordinate Frame.
     """
     POSE = "pose"
 
@@ -350,7 +360,6 @@ class OsefKeys(Enum):
     - none or one:     Zones Def                      (ZONES_DEF)
     - none or one:     Zones Objects Binding          (ZONES_OBJECTS_BINDING) [DEPRECATED USAGE]
     - none or one:     Zones Objects Binding 32 Bits  (ZONES_OBJECTS_BINDING_32_BITS)
-    - none or one:     Smoothed Pose                  (SMOOTHED_POSE)
     - none or one:     Height Map                     (HEIGHT_MAP)
     """
     SCAN_FRAME = "scan_frame"
@@ -359,6 +368,8 @@ class OsefKeys(Enum):
     Tracked Objects
     **Output when**: Tracking is enabled.
     **Purpose**: Properties of tracked objects, which includes centroid, bbox, speed...
+    For further details, see: [Object Tracking
+    Data](https://docs.outsight.ai/software/understanding-osef-data/object-tracking-data).
     Contains following sub-TLVs:
     - exactly one:     Number of Objects              (NUMBER_OF_OBJECTS)
     - exactly one:     Object ID 32 Bits              (OBJECT_ID_32_BITS)
@@ -375,6 +386,7 @@ class OsefKeys(Enum):
     Bbox Sizes
     **Output when**: Tracking is enabled.
     **Purpose**: Define bounding boxes around each tracked object.
+    The bounding box is extended/cropped in a way to always touch the ground along the z axis.
     A bounding box is defined by its 3 dimensions, on x, y, z axes, centered on Pose Array.
     **Format**: Array of bounding box sizes, three single-precision floats per object:
     * x : meters, range [ -inf .. +inf ]
@@ -582,10 +594,12 @@ class OsefKeys(Enum):
 
     """
     Ego Motion
-    **Output when**: Slam is enabled.
+    **Output when**: SLAM is enabled.
     Contains following sub-TLVs:
     - exactly one:     Pose Relative                  (POSE_RELATIVE)
     - none or one:     Predicted Position             (PREDICTED_POSITION)
+    - none or one:     Smoothed Pose                  (SMOOTHED_POSE)
+    - none or one:     Divergence Indicator           (DIVERGENCE_INDICATOR)
     """
     EGO_MOTION = "ego_motion"
 
@@ -603,8 +617,8 @@ class OsefKeys(Enum):
     Geographic Pose
     **Deprecated since**: 5.3
     **Instead, use**: "Geographic Pose Precise" (Type 57)
-    **Purpose**: Represents the geographic pose, output from the relocation processing, expressed in decimal degrees
-    notation (latitude, longitude & heading).
+    **Purpose**: Represents the geographic pose, output from the relocalization processing, expressed in decimal
+    degrees notation (latitude, longitude & heading).
     **Format**: Concatenation of 3 single precision (32 bits) floats [lat, long, heading].
     * Single-precision floating-point (float32) : latitude in decimal degrees, range [ -90.0 .. 90.0 ]
     * Single-precision floating-point (float32) : longitude in decimal degrees, range [ -180.0 .. 180.0 ]
@@ -705,6 +719,8 @@ class OsefKeys(Enum):
     The SLAM algorithm may not run on all tracked objects. When the SLAM does not run on an object,
     let say on object number 5, all floats of the related pose in this array, e.g. the fifth, are equal to zero.
     Moreover, the related element of type 39 "Object properties", e.g. the fifth, has its third bit equal to zero.
+    For further details see: [Spatial Data / Static
+    Tracking](https://docs.outsight.ai/software/understanding-osef-data/spatial-data-tracking).
     **Format**: The binary payload is a repetition of the following content, one per tracked object:
     * single-precision floats Tx, Ty and Tz represent the translation vector T to get the position coordinates in
     meters.
@@ -733,8 +749,8 @@ class OsefKeys(Enum):
     Geographic Pose Precise
     **Output when**: Relocalization in a reference map and georeferencing are enabled.
     So in processing config: slam.enable set to true, slam.reference_map defined and slam.georeferencing set to true.
-    **Purpose**: Represents the geographic pose, output from the relocation processing, expressed in decimal degrees
-    notation (latitude, longitude & heading).
+    **Purpose**: Represents the geographic pose, output from the relocalization processing, expressed in decimal
+    degrees notation (latitude, longitude & heading).
     **Format**: Concatenation of 2 double precision (64 bits) and a single precision (32 bits) floats [lat, long,
     heading].
     * Double-precision floating-point (float64) : latitude in decimal degrees, range [ -90.0 .. 90.0 ]
@@ -753,7 +769,8 @@ class OsefKeys(Enum):
     """
     Smoothed Pose
     **Output when**: SLAM and slam.smooth_output pose are enabled.
-    **Purpose**: Smoothed pose of the LiDAR, in order to smooth out the discrepancies.
+    **Purpose**: Smoothed pose of the absolute LiDAR pose, to use when speed of the vehicle is low as filtering will
+    introduce a slight delay.
     **Format**: Concatenation of 12 floats of 32-bits each, see type Pose for more details.
     """
     _SMOOTHED_POSE = "smoothed_pose"
@@ -844,6 +861,78 @@ class OsefKeys(Enum):
     """
     _HEIGHT_MAP_POINTS = "height_map_points"
 
+    """
+    Divergence Indicator
+    **Since**: 5.6.0
+    **Output when**: Relocalization is enabled (SLAM with a reference map).
+    **Format**: One float value.
+    **Purpose**: Indicates if SLAM seems to have diverged.
+    - 0 means SLAM algorithm does not seem to have diverged.
+    - 1 means SLAM algorithm seems to have diverged, the associated pose is not trustworthy.
+    """
+    DIVERGENCE_INDICATOR = "divergence_indicator"
+
+    """
+    Carla Tag Array
+    **Output when**: generated by Carla Scenario Generator.
+    **Format**: list of unsigned 8-bits integers, using enum Carla Tag enum.
+    **Purpose**: keeps the tag value, attributed by the Carla Simulator, to each point of the pointcloud.
+    """
+    _CARLA_TAG_ARRAY = "carla_tag_array"
+
+    """
+    Background Scene Params
+    **Output when**: Multi-LiDARS Tracking is enabled, in the background stream between edge and fusion.
+    **Purpose**: All params to initialize the background scene and be able to interpret Background Stream Fragment
+    (type 76) packets
+    """
+    _BACKGROUND_SCENE_PARAMS = "background_scene_params"
+
+    """
+    Background Scene Params General
+    **Output when**: Multi-LiDARS Tracking is enabled, in the background stream between edge and fusion.
+    **Format**: the following concatenated values:
+      * width: 32-bits unsigned integer, number of columns of the background scene array
+      * height: 32-bits unsigned integer, number of rows of the background scene array
+      * first azimuth: single-precision float, azimuth of the first column of the background scene array, in degrees
+      * azimuth step: single-precision float, difference between the azimuths of two consecutive columns of the
+    background scene array, in degrees
+    """
+    _BACKGROUND_SCENE_PARAMS_GENERAL = "background_scene_params_general"
+
+    """
+    Background Scene Params Elevations
+    **Output when**: generated by Carla Scenario Generator.
+    **Format**: list of single precision floats, each one representing the elevation of a row in the background scene
+    array, in degrees
+    """
+    _BACKGROUND_SCENE_PARAMS_ELEVATIONS = "background_scene_params_elevations"
+
+    """
+    Background Scene Fragment
+    **Output when**: Multi-LiDARS Tracking is enabled, in the background stream between edge and fusion.
+    **Purpose**: A fragment of the background scene array
+    """
+    _BACKGROUND_SCENE_FRAGMENT = "background_scene_fragment"
+
+    """
+    Background Scene Fragment Info
+    **Output when**: in background stream between edge and fusion, in tracking mode
+    **Format**: the following concatenated values:
+      * first_index: 32-bites unsigned integer, index of the first cell in background scene array, computed as x *
+    height + y, the second cell index is first_index+1, etc., with a rollover on width * height
+      * cells_number: 32-bites unsigned integer, number of cells contained in the fragment
+    """
+    _BACKGROUND_SCENE_FRAGMENT_INFO = "background_scene_fragment_info"
+
+    """
+    Background Scene Fragment Distances
+    **Output when**: Multi-LiDARS Tracking is enabled, in the background stream between edge and fusion.
+    **Format**: list of single precision floats, each one representing the farthest background distance for the
+    corresponding cell
+    """
+    _BACKGROUND_SCENE_FRAGMENT_DISTANCES = "background_scene_fragment_distances"
+
 
 class ClassId(IntEnum):
     """Tracked object class ID"""
@@ -900,3 +989,31 @@ class LidarModelId(IntEnum):
     FAKE_LIDAR = 16
     HESAI_PANDARXT32M2X = 17
     ROBOSENSE_M1 = 18
+
+
+class CarlaTag(IntEnum):
+    """Carla Tag"""
+
+    UNLABELED = 0
+    BUILDING = 1
+    FENCE = 2
+    OTHER = 3
+    PEDESTRIAN = 4
+    POLE = 5
+    ROADLINE = 6
+    ROAD = 7
+    SIDEWALK = 8
+    VEGETATION = 9
+    VEHICLES = 10
+    WALL = 11
+    TRAFFICSIGN = 12
+    SKY = 13
+    GROUND = 14
+    BRIDGE = 15
+    RAILTRACK = 16
+    GUARDRAIL = 17
+    TRAFFICLIGHT = 18
+    STATIC = 19
+    DYNAMIC = 20
+    WATER = 21
+    TERRAIN = 22
