@@ -395,7 +395,7 @@ outsight_types = {
     ),
     OsefTypes._SMOOTHED_POSE.value: TypeInfo(
         OsefKeys._SMOOTHED_POSE.value,
-        LeafInfo(_unpackers._pose_array_unpacker, _packers._pose_array_packer),
+        LeafInfo(_unpackers._pose_unpacker, _packers._pose_packer),
     ),
     OsefTypes._HEIGHT_MAP.value: TypeInfo(
         OsefKeys._HEIGHT_MAP.value, InternalNodeInfo(dict)
@@ -407,6 +407,18 @@ outsight_types = {
             _packers._array_packer,
         ),
     ),
+    OsefTypes.DIVERGENCE_INDICATOR.value: TypeInfo(
+        OsefKeys.DIVERGENCE_INDICATOR.value,
+        LeafInfo(
+            _unpackers._get_value_unpacker("<f"), _packers._get_value_packer("<f")
+        ),
+    ),
+    OsefTypes._CARLA_TAG_ARRAY.value: TypeInfo(
+        OsefKeys._CARLA_TAG_ARRAY.value,
+        LeafInfo(
+            _unpackers._get_array_unpacker(np.dtype(np.uint32)), _packers._array_packer
+        ),
+    ),
 }
 
 
